#
# spec file for package 2ping
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           2ping
Version:        4.5.1+20241102
Release:        1.1
Summary:        Bi-directional ping utility
License:        MPL-2.0
URL:            https://www.finnie.org/software/2ping/
Source0:        %{name}-%{version}.tar.xz
Source2:        %{name}.keyring
Patch0:         harden_2ping.service.patch
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-devel >= 3.6
BuildRequires:  python3-distro
BuildRequires:  python3-dnspython
BuildRequires:  python3-netifaces
BuildRequires:  python3-pycryptodomex
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
BuildRequires:  systemd-rpm-macros
Requires:       python3 >= 3.6
Recommends:     python3-distro
Recommends:     python3-dnspython
Recommends:     python3-netifaces
Recommends:     python3-pycryptodomex
BuildArch:      noarch
%{?systemd_requires}

%description
2ping is a bi-directional ping utility. It uses 3-way pings (akin to TCP SYN,
SYN/ACK, ACK) and after-the-fact state comparison between a 2ping listener and
a 2ping client to determine which direction packet loss occurs.

%prep
%autosetup

%build
%python3_build

%install
%python3_install
install -Dp -m 0644 2ping.service %{buildroot}%{_unitdir}/2ping.service
install -Dp -m 0644 doc/2ping.1 %{buildroot}%{_mandir}/man1/2ping.1
install -Dp -m 0644 doc/2ping.1 %{buildroot}%{_mandir}/man1/2ping6.1

mkdir -p %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc2ping

# Fix python shebangs
%python3_fix_shebang

# create symlinks for man pages
%fdupes -s %{buildroot}%{_mandir}
# create hardlinks for the rest
%fdupes %{buildroot}%{_prefix}

%check
py.test -v

%pre
%service_add_pre 2ping.service

%post
%service_add_post 2ping.service

%preun
%service_del_preun 2ping.service

%postun
%service_del_postun 2ping.service

%files
%license COPYING.md
%doc ChangeLog.md README.md
%{_bindir}/%{name}
%{_bindir}/%{name}6
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}6.1%{?ext_man}
%{_sbindir}/rc%{name}
%{_unitdir}/2ping.service
%{python3_sitelib}/*

%changelog
* Mon Dec  2 2024 jslaby@suse.cz
- Update to version 4.5.1+20241102:
  * get_system_addresses: Guard against netifaces race condition
  * Remove snapcraft definition
  * 2ping.service: Use DynamicUser=yes instead of User=nobody
  * End stats updates
  * Argument parsing cleanups
  * Fix duplicated AUTHOR/AUTHORS section in manpage
  * Tox updates
  * Change license from GPLv2 to Mozilla Public License 2.0
* Wed Oct  4 2023 Daniel Garcia <daniel.garcia@suse.com>
- Remove dependency on /usr/bin/python3 using %%python3_fix_shebang
  macro, bsc#1212476
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Tue Aug 10 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added patch(es):
  * harden_2ping.service.patch
* Mon Jun 14 2021 Jiri Slaby <jslaby@suse.cz>
- python symbol is not provided by python 3, use proper python3
* Mon Mar 22 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 4.5.1
  * 2ping.bash_completion: Make more resilient to failure / missing
    features.
  * Minimum Python version changed from 3.5 to 3.6.
  * Minor no-op code and distribution updates.
* Mon Jan 25 2021 Jiri Slaby <jslaby@suse.cz>
- use one python, not singlespec
* Thu Jul  9 2020 Matthias Eliasson <elimat@opensuse.org>
- Change optional requirements to recommends since they just enhance the tool
- Use correct package names for the recommends
* Thu Jul  2 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 4.5
  * Added PyCryptodome support (recommended over PyCrypto, though the latter is still detected/supported).
  * Replaced best_poller module with Python native selectors module.
  * Changed --flood output: dots/backspaces are no longer printed, and loss results / errors display full details.
  * --audible tones will only occur if stdout is a TTY.
  * Improved hostname/IP display edge cases.
  * Added an AF_UNIX --loopback test mode.
  * Listener sockets are added and removed as needed, instead of being re-created on each rescan.
  * Listener sockets are automatically rescanned periodically.
  * Multiple systemd sockets are now allowed.
  * A run can be both a listener and a client at the same time (mainly useful for smoke testing).
  * Other socket handling refactoring.
  * Other code refactoring.
  * Listener statistics are displayer per-bind.
  * Many, many testing/CI improvements.
- Remove groups in spec
- Package systemd service unit
- Add missing optional build requirements to enable all available options
- Some other clean up in spec
* Sun Feb  3 2019 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to version 4.3
  * Add --srv-service
  * Change --adaptive behavior to better match ping -A
  * Fix typos in manpage
- Ran spec-cleaner
- Fix rpmlint duplicate error with fdupes
* Mon Oct  8 2018 sean@suspend.net
- Update to version 4.2
  * Added SIGHUP handling of listener processes
  * Added an example bash_completion script
  * Better cleanup handling of peer information
* Sat Aug 11 2018 rpm@fthiessen.de
- Update to version 4.1.2
  * Fix UTF-8 tests when run with invalid locale.
  * Fix cleanup on non-encrypted sessions.
* Wed May 23 2018 kbabioch@suse.com
- Use OpenPGP signature provided upstream
- Added 2ping.keyring, which contains the key from the author
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to version 4.1
  * Fixed --fuzz CRC function.
  * Added --encrypt option for shared-secret encrypted packets.
  * Added --listen --all-interfaces option for automatically binding to
  all interface IPs (requires Python netifaces module).
  * Simplified monotonic_clock functionality, relying on Python 3 for
  most functionality, reducing the possibility of platform bugs.
- Includes changes from 4.0
  * Rewrite to Python 3 (3.4 or higher).
  * Fixed hmac-sha256 handling, added hmac-sha512.
  * --nagios will now work when combined with --deadline, in addition to
  - -count.
  * Added Wireshark Lua dissector and sample capture.
  * Added battery level (ExtID 0x88a1f7c7).  Note that while 2ping
  recognizes the new option in incoming packets, it currently does not
  have the capability to send battery levels.
* Fri Jul 29 2016 jengelh@inai.de
- Make rpmlint happy by avoiding installation in %%build.
* Sun Jul 24 2016 p.drouand@gmail.com
- Update to version 3.2.1
  * Please read the ChangeLog; not able to track all changes since
    previous version
- Upstream moved to python
  * Remove %%{perl_requires} dependency
  * Remove perl recommendations; perl(Digest::CRC), perl(Digest::MD5),
    perl(Digest::SHA) and perl(IO::Socket::INET6)
  * Add python-devel and python-setuptools requirements
- Use official tarball and download Url
- Remove obsolete 2ping-fix-use-of-uninitialized-warning.patch
* Fri Apr  3 2015 jslaby@suse.com
- update to 1397618874.f2c2047
- 2ping-fix-use-of-uninitialized-warning.patch: add
* Wed Nov 10 2010 jslaby@suse.de
- Initial package (version 1.0)
